# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .account_project import *
from .account_ssh_key import *
from .apple_silicon_server import *
from .baremetal_server import *
from .block_snapshot import *
from .block_volume import *
from .cockpit import *
from .cockpit_alert_manager import *
from .cockpit_grafana_user import *
from .cockpit_source import *
from .cockpit_token import *
from .container import *
from .container_cron import *
from .container_domain import *
from .container_namespace import *
from .container_token import *
from .container_trigger import *
from .database import *
from .database_acl import *
from .database_backup import *
from .database_instance import *
from .database_privilege import *
from .database_read_replica import *
from .database_user import *
from .domain_record import *
from .domain_zone import *
from .edge_services_backend_stage import *
from .edge_services_cache_stage import *
from .edge_services_dns_stage import *
from .edge_services_head_stage import *
from .edge_services_pipeline import *
from .edge_services_plan import *
from .edge_services_route_stage import *
from .edge_services_tls_stage import *
from .edge_services_waf_stage import *
from .file_filesystem import *
from .flexible_ip import *
from .flexible_ip_mac_address import *
from .function import *
from .function_cron import *
from .function_domain import *
from .function_namespace import *
from .function_token import *
from .function_trigger import *
from .get_account_project import *
from .get_account_ssh_key import *
from .get_availability_zones import *
from .get_baremetal_offer import *
from .get_baremetal_option import *
from .get_baremetal_os import *
from .get_baremetal_server import *
from .get_billing_consumptions import *
from .get_billing_invoices import *
from .get_block_snapshot import *
from .get_block_volume import *
from .get_cockpit import *
from .get_cockpit_source import *
from .get_config import *
from .get_container import *
from .get_container_namespace import *
from .get_database import *
from .get_database_acl import *
from .get_database_backup import *
from .get_database_instance import *
from .get_database_privilege import *
from .get_domain_record import *
from .get_domain_zone import *
from .get_flexible_ip import *
from .get_flexible_ips import *
from .get_function import *
from .get_function_namespace import *
from .get_iam_api_key import *
from .get_iam_application import *
from .get_iam_group import *
from .get_iam_ssh_key import *
from .get_iam_user import *
from .get_instance_image import *
from .get_instance_ip import *
from .get_instance_placement_group import *
from .get_instance_private_nic import *
from .get_instance_security_group import *
from .get_instance_server import *
from .get_instance_servers import *
from .get_instance_snapshot import *
from .get_instance_volume import *
from .get_iot_device import *
from .get_iot_hub import *
from .get_ipam_ip import *
from .get_ipam_ips import *
from .get_k8s_version import *
from .get_kubernetes_cluster import *
from .get_kubernetes_node_pool import *
from .get_lb_acls import *
from .get_lb_backend import *
from .get_lb_backends import *
from .get_lb_frontend import *
from .get_lb_frontends import *
from .get_lb_ips import *
from .get_lb_route import *
from .get_lb_routes import *
from .get_lbs import *
from .get_loadbalancer import *
from .get_loadbalancer_certificate import *
from .get_loadbalancer_ip import *
from .get_marketplace_image import *
from .get_mnq_sns import *
from .get_mnq_sqs import *
from .get_mongo_db_instance import *
from .get_object_bucket import *
from .get_object_bucket_policy import *
from .get_redis_cluster import *
from .get_registry_image import *
from .get_registry_image_tag import *
from .get_registry_namespace import *
from .get_secret import *
from .get_secret_version import *
from .get_tem_domain import *
from .get_vpc import *
from .get_vpc_gateway_network import *
from .get_vpc_private_network import *
from .get_vpc_public_gateway import *
from .get_vpc_public_gateway_dhcp import *
from .get_vpc_public_gateway_dhcp_reservation import *
from .get_vpc_public_gateway_ip import *
from .get_vpc_public_pat_rule import *
from .get_vpc_routes import *
from .get_vpcs import *
from .get_web_host_offer import *
from .get_webhosting import *
from .iam_api_key import *
from .iam_application import *
from .iam_group import *
from .iam_group_membership import *
from .iam_policy import *
from .iam_ssh_key import *
from .iam_user import *
from .inference_deployment import *
from .instance_image import *
from .instance_ip import *
from .instance_ip_reverse_dns import *
from .instance_placement_group import *
from .instance_private_nic import *
from .instance_security_group import *
from .instance_security_group_rules import *
from .instance_server import *
from .instance_snapshot import *
from .instance_user_data import *
from .instance_volume import *
from .iot_device import *
from .iot_hub import *
from .iot_network import *
from .iot_route import *
from .ipam_ip import *
from .ipam_ip_reverse_dns import *
from .job_definition import *
from .key_manager_key import *
from .kubernetes_cluster import *
from .kubernetes_node_pool import *
from .loadbalancer import *
from .loadbalancer_acl import *
from .loadbalancer_backend import *
from .loadbalancer_certificate import *
from .loadbalancer_frontend import *
from .loadbalancer_ip import *
from .loadbalancer_route import *
from .mnq_nats_account import *
from .mnq_nats_credentials import *
from .mnq_sns import *
from .mnq_sns_credentials import *
from .mnq_sns_topic import *
from .mnq_sns_topic_subscription import *
from .mnq_sqs import *
from .mnq_sqs_credentials import *
from .mnq_sqs_queue import *
from .mongo_db_instance import *
from .mongo_db_snapshot import *
from .object_bucket import *
from .object_bucket_acl import *
from .object_bucket_lock_configuration import *
from .object_bucket_policy import *
from .object_bucket_website_configuration import *
from .object_item import *
from .provider import *
from .rdb_snapshot import *
from .redis_cluster import *
from .registry_namespace import *
from .sdb_database import *
from .secret import *
from .secret_version import *
from .tem_domain import *
from .tem_domain_validation import *
from .tem_webhook import *
from .vpc import *
from .vpc_gateway_network import *
from .vpc_private_network import *
from .vpc_public_gateway import *
from .vpc_public_gateway_dhcp import *
from .vpc_public_gateway_dhcp_reservation import *
from .vpc_public_gateway_ip import *
from .vpc_public_gateway_ip_reverse_dns import *
from .vpc_public_gateway_pat_rule import *
from .vpc_route import *
from .webhosting import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumiverse_scaleway.account as __account
    account = __account
    import pulumiverse_scaleway.applesilicon as __applesilicon
    applesilicon = __applesilicon
    import pulumiverse_scaleway.autoscaling as __autoscaling
    autoscaling = __autoscaling
    import pulumiverse_scaleway.billing as __billing
    billing = __billing
    import pulumiverse_scaleway.block as __block
    block = __block
    import pulumiverse_scaleway.config as __config
    config = __config
    import pulumiverse_scaleway.containers as __containers
    containers = __containers
    import pulumiverse_scaleway.databases as __databases
    databases = __databases
    import pulumiverse_scaleway.domain as __domain
    domain = __domain
    import pulumiverse_scaleway.elasticmetal as __elasticmetal
    elasticmetal = __elasticmetal
    import pulumiverse_scaleway.functions as __functions
    functions = __functions
    import pulumiverse_scaleway.hosting as __hosting
    hosting = __hosting
    import pulumiverse_scaleway.iam as __iam
    iam = __iam
    import pulumiverse_scaleway.inference as __inference
    inference = __inference
    import pulumiverse_scaleway.instance as __instance
    instance = __instance
    import pulumiverse_scaleway.iot as __iot
    iot = __iot
    import pulumiverse_scaleway.ipam as __ipam
    ipam = __ipam
    import pulumiverse_scaleway.job as __job
    job = __job
    import pulumiverse_scaleway.kubernetes as __kubernetes
    kubernetes = __kubernetes
    import pulumiverse_scaleway.loadbalancers as __loadbalancers
    loadbalancers = __loadbalancers
    import pulumiverse_scaleway.mnq as __mnq
    mnq = __mnq
    import pulumiverse_scaleway.mongodb as __mongodb
    mongodb = __mongodb
    import pulumiverse_scaleway.network as __network
    network = __network
    import pulumiverse_scaleway.object as __object
    object = __object
    import pulumiverse_scaleway.observability as __observability
    observability = __observability
    import pulumiverse_scaleway.redis as __redis
    redis = __redis
    import pulumiverse_scaleway.registry as __registry
    registry = __registry
    import pulumiverse_scaleway.secrets as __secrets
    secrets = __secrets
    import pulumiverse_scaleway.tem as __tem
    tem = __tem
else:
    account = _utilities.lazy_import('pulumiverse_scaleway.account')
    applesilicon = _utilities.lazy_import('pulumiverse_scaleway.applesilicon')
    autoscaling = _utilities.lazy_import('pulumiverse_scaleway.autoscaling')
    billing = _utilities.lazy_import('pulumiverse_scaleway.billing')
    block = _utilities.lazy_import('pulumiverse_scaleway.block')
    config = _utilities.lazy_import('pulumiverse_scaleway.config')
    containers = _utilities.lazy_import('pulumiverse_scaleway.containers')
    databases = _utilities.lazy_import('pulumiverse_scaleway.databases')
    domain = _utilities.lazy_import('pulumiverse_scaleway.domain')
    elasticmetal = _utilities.lazy_import('pulumiverse_scaleway.elasticmetal')
    functions = _utilities.lazy_import('pulumiverse_scaleway.functions')
    hosting = _utilities.lazy_import('pulumiverse_scaleway.hosting')
    iam = _utilities.lazy_import('pulumiverse_scaleway.iam')
    inference = _utilities.lazy_import('pulumiverse_scaleway.inference')
    instance = _utilities.lazy_import('pulumiverse_scaleway.instance')
    iot = _utilities.lazy_import('pulumiverse_scaleway.iot')
    ipam = _utilities.lazy_import('pulumiverse_scaleway.ipam')
    job = _utilities.lazy_import('pulumiverse_scaleway.job')
    kubernetes = _utilities.lazy_import('pulumiverse_scaleway.kubernetes')
    loadbalancers = _utilities.lazy_import('pulumiverse_scaleway.loadbalancers')
    mnq = _utilities.lazy_import('pulumiverse_scaleway.mnq')
    mongodb = _utilities.lazy_import('pulumiverse_scaleway.mongodb')
    network = _utilities.lazy_import('pulumiverse_scaleway.network')
    object = _utilities.lazy_import('pulumiverse_scaleway.object')
    observability = _utilities.lazy_import('pulumiverse_scaleway.observability')
    redis = _utilities.lazy_import('pulumiverse_scaleway.redis')
    registry = _utilities.lazy_import('pulumiverse_scaleway.registry')
    secrets = _utilities.lazy_import('pulumiverse_scaleway.secrets')
    tem = _utilities.lazy_import('pulumiverse_scaleway.tem')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "scaleway",
  "mod": "account/project",
  "fqn": "pulumiverse_scaleway.account",
  "classes": {
   "scaleway:account/project:Project": "Project"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "account/sshKey",
  "fqn": "pulumiverse_scaleway.account",
  "classes": {
   "scaleway:account/sshKey:SshKey": "SshKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "applesilicon/server",
  "fqn": "pulumiverse_scaleway.applesilicon",
  "classes": {
   "scaleway:applesilicon/server:Server": "Server"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "autoscaling/instanceGroup",
  "fqn": "pulumiverse_scaleway.autoscaling",
  "classes": {
   "scaleway:autoscaling/instanceGroup:InstanceGroup": "InstanceGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "autoscaling/instancePolicy",
  "fqn": "pulumiverse_scaleway.autoscaling",
  "classes": {
   "scaleway:autoscaling/instancePolicy:InstancePolicy": "InstancePolicy"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "autoscaling/instanceTemplate",
  "fqn": "pulumiverse_scaleway.autoscaling",
  "classes": {
   "scaleway:autoscaling/instanceTemplate:InstanceTemplate": "InstanceTemplate"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "block/snapshot",
  "fqn": "pulumiverse_scaleway.block",
  "classes": {
   "scaleway:block/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "block/volume",
  "fqn": "pulumiverse_scaleway.block",
  "classes": {
   "scaleway:block/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "containers/container",
  "fqn": "pulumiverse_scaleway.containers",
  "classes": {
   "scaleway:containers/container:Container": "Container"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "containers/cron",
  "fqn": "pulumiverse_scaleway.containers",
  "classes": {
   "scaleway:containers/cron:Cron": "Cron"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "containers/domain",
  "fqn": "pulumiverse_scaleway.containers",
  "classes": {
   "scaleway:containers/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "containers/namespace",
  "fqn": "pulumiverse_scaleway.containers",
  "classes": {
   "scaleway:containers/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "containers/token",
  "fqn": "pulumiverse_scaleway.containers",
  "classes": {
   "scaleway:containers/token:Token": "Token"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "containers/trigger",
  "fqn": "pulumiverse_scaleway.containers",
  "classes": {
   "scaleway:containers/trigger:Trigger": "Trigger"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/acl",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/database",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/database:Database": "Database"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/databaseBackup",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/databaseBackup:DatabaseBackup": "DatabaseBackup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/instance",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/privilege",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/privilege:Privilege": "Privilege"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/readReplica",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/readReplica:ReadReplica": "ReadReplica"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/serverlessDatabase",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/serverlessDatabase:ServerlessDatabase": "ServerlessDatabase"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/snapshot",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/user",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/user:User": "User"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "domain/record",
  "fqn": "pulumiverse_scaleway.domain",
  "classes": {
   "scaleway:domain/record:Record": "Record"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "domain/registration",
  "fqn": "pulumiverse_scaleway.domain",
  "classes": {
   "scaleway:domain/registration:Registration": "Registration"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "domain/zone",
  "fqn": "pulumiverse_scaleway.domain",
  "classes": {
   "scaleway:domain/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "elasticmetal/ip",
  "fqn": "pulumiverse_scaleway.elasticmetal",
  "classes": {
   "scaleway:elasticmetal/ip:Ip": "Ip"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "elasticmetal/ipMacAddress",
  "fqn": "pulumiverse_scaleway.elasticmetal",
  "classes": {
   "scaleway:elasticmetal/ipMacAddress:IpMacAddress": "IpMacAddress"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "elasticmetal/server",
  "fqn": "pulumiverse_scaleway.elasticmetal",
  "classes": {
   "scaleway:elasticmetal/server:Server": "Server"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "functions/cron",
  "fqn": "pulumiverse_scaleway.functions",
  "classes": {
   "scaleway:functions/cron:Cron": "Cron"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "functions/domain",
  "fqn": "pulumiverse_scaleway.functions",
  "classes": {
   "scaleway:functions/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "functions/function",
  "fqn": "pulumiverse_scaleway.functions",
  "classes": {
   "scaleway:functions/function:Function": "Function"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "functions/namespace",
  "fqn": "pulumiverse_scaleway.functions",
  "classes": {
   "scaleway:functions/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "functions/token",
  "fqn": "pulumiverse_scaleway.functions",
  "classes": {
   "scaleway:functions/token:Token": "Token"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "functions/trigger",
  "fqn": "pulumiverse_scaleway.functions",
  "classes": {
   "scaleway:functions/trigger:Trigger": "Trigger"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "hosting/hosting",
  "fqn": "pulumiverse_scaleway.hosting",
  "classes": {
   "scaleway:hosting/hosting:Hosting": "Hosting"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/apiKey",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/apiKey:ApiKey": "ApiKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/application",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/application:Application": "Application"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/group",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/group:Group": "Group"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/groupMembership",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/groupMembership:GroupMembership": "GroupMembership"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/policy",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/sshKey",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/sshKey:SshKey": "SshKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/user",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/user:User": "User"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/accountProject",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/accountProject:AccountProject": "AccountProject"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/accountSshKey",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/accountSshKey:AccountSshKey": "AccountSshKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/appleSiliconServer",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/appleSiliconServer:AppleSiliconServer": "AppleSiliconServer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/baremetalServer",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/baremetalServer:BaremetalServer": "BaremetalServer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/blockSnapshot",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/blockSnapshot:BlockSnapshot": "BlockSnapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/blockVolume",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/blockVolume:BlockVolume": "BlockVolume"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/cockpit",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/cockpit:Cockpit": "Cockpit"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/cockpitAlertManager",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/cockpitAlertManager:CockpitAlertManager": "CockpitAlertManager"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/cockpitGrafanaUser",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/cockpitGrafanaUser:CockpitGrafanaUser": "CockpitGrafanaUser"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/cockpitSource",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/cockpitSource:CockpitSource": "CockpitSource"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/cockpitToken",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/cockpitToken:CockpitToken": "CockpitToken"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/container",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/container:Container": "Container"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerCron",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerCron:ContainerCron": "ContainerCron"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerDomain",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerDomain:ContainerDomain": "ContainerDomain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerNamespace",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerNamespace:ContainerNamespace": "ContainerNamespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerToken",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerToken:ContainerToken": "ContainerToken"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerTrigger",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerTrigger:ContainerTrigger": "ContainerTrigger"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/database",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/database:Database": "Database"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseAcl",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseAcl:DatabaseAcl": "DatabaseAcl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseBackup",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseBackup:DatabaseBackup": "DatabaseBackup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseInstance",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseInstance:DatabaseInstance": "DatabaseInstance"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databasePrivilege",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databasePrivilege:DatabasePrivilege": "DatabasePrivilege"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseReadReplica",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseReadReplica:DatabaseReadReplica": "DatabaseReadReplica"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseUser",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseUser:DatabaseUser": "DatabaseUser"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/domainRecord",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/domainRecord:DomainRecord": "DomainRecord"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/domainZone",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/domainZone:DomainZone": "DomainZone"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesBackendStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesBackendStage:EdgeServicesBackendStage": "EdgeServicesBackendStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesCacheStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesCacheStage:EdgeServicesCacheStage": "EdgeServicesCacheStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesDnsStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesDnsStage:EdgeServicesDnsStage": "EdgeServicesDnsStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesHeadStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesHeadStage:EdgeServicesHeadStage": "EdgeServicesHeadStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesPipeline",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesPipeline:EdgeServicesPipeline": "EdgeServicesPipeline"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesPlan",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesPlan:EdgeServicesPlan": "EdgeServicesPlan"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesRouteStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesRouteStage:EdgeServicesRouteStage": "EdgeServicesRouteStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesTlsStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesTlsStage:EdgeServicesTlsStage": "EdgeServicesTlsStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesWafStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesWafStage:EdgeServicesWafStage": "EdgeServicesWafStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/fileFilesystem",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/fileFilesystem:FileFilesystem": "FileFilesystem"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/flexibleIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/flexibleIp:FlexibleIp": "FlexibleIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/flexibleIpMacAddress",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/flexibleIpMacAddress:FlexibleIpMacAddress": "FlexibleIpMacAddress"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/function",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/function:Function": "Function"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionCron",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionCron:FunctionCron": "FunctionCron"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionDomain",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionDomain:FunctionDomain": "FunctionDomain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionNamespace",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionNamespace:FunctionNamespace": "FunctionNamespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionToken",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionToken:FunctionToken": "FunctionToken"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionTrigger",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionTrigger:FunctionTrigger": "FunctionTrigger"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamApiKey",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamApiKey:IamApiKey": "IamApiKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamApplication",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamApplication:IamApplication": "IamApplication"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamGroup",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamGroup:IamGroup": "IamGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamGroupMembership",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamGroupMembership:IamGroupMembership": "IamGroupMembership"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamPolicy",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamPolicy:IamPolicy": "IamPolicy"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamSshKey",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamSshKey:IamSshKey": "IamSshKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamUser",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamUser:IamUser": "IamUser"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/inferenceDeployment",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/inferenceDeployment:InferenceDeployment": "InferenceDeployment"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceImage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceImage:InstanceImage": "InstanceImage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceIp:InstanceIp": "InstanceIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceIpReverseDns",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceIpReverseDns:InstanceIpReverseDns": "InstanceIpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instancePlacementGroup",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instancePlacementGroup:InstancePlacementGroup": "InstancePlacementGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instancePrivateNic",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instancePrivateNic:InstancePrivateNic": "InstancePrivateNic"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceSecurityGroup",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceSecurityGroup:InstanceSecurityGroup": "InstanceSecurityGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceSecurityGroupRules",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceSecurityGroupRules:InstanceSecurityGroupRules": "InstanceSecurityGroupRules"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceServer",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceServer:InstanceServer": "InstanceServer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceSnapshot",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceSnapshot:InstanceSnapshot": "InstanceSnapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceUserData",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceUserData:InstanceUserData": "InstanceUserData"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceVolume",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceVolume:InstanceVolume": "InstanceVolume"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iotDevice",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iotDevice:IotDevice": "IotDevice"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iotHub",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iotHub:IotHub": "IotHub"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iotNetwork",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iotNetwork:IotNetwork": "IotNetwork"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iotRoute",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iotRoute:IotRoute": "IotRoute"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/ipamIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/ipamIp:IpamIp": "IpamIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/ipamIpReverseDns",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/ipamIpReverseDns:IpamIpReverseDns": "IpamIpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/jobDefinition",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/jobDefinition:JobDefinition": "JobDefinition"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/keyManagerKey",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/keyManagerKey:KeyManagerKey": "KeyManagerKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/kubernetesCluster",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/kubernetesCluster:KubernetesCluster": "KubernetesCluster"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/kubernetesNodePool",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/kubernetesNodePool:KubernetesNodePool": "KubernetesNodePool"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancer",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancer:Loadbalancer": "Loadbalancer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerAcl",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerAcl:LoadbalancerAcl": "LoadbalancerAcl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerBackend",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerBackend:LoadbalancerBackend": "LoadbalancerBackend"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerCertificate",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerCertificate:LoadbalancerCertificate": "LoadbalancerCertificate"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerFrontend",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerFrontend:LoadbalancerFrontend": "LoadbalancerFrontend"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerIp:LoadbalancerIp": "LoadbalancerIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerRoute",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerRoute:LoadbalancerRoute": "LoadbalancerRoute"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqNatsAccount",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqNatsAccount:MnqNatsAccount": "MnqNatsAccount"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqNatsCredentials",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqNatsCredentials:MnqNatsCredentials": "MnqNatsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSns",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSns:MnqSns": "MnqSns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSnsCredentials",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSnsCredentials:MnqSnsCredentials": "MnqSnsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSnsTopic",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSnsTopic:MnqSnsTopic": "MnqSnsTopic"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSnsTopicSubscription",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSnsTopicSubscription:MnqSnsTopicSubscription": "MnqSnsTopicSubscription"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSqs",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSqs:MnqSqs": "MnqSqs"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSqsCredentials",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSqsCredentials:MnqSqsCredentials": "MnqSqsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSqsQueue",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSqsQueue:MnqSqsQueue": "MnqSqsQueue"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mongoDbInstance",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mongoDbInstance:MongoDbInstance": "MongoDbInstance"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mongoDbSnapshot",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mongoDbSnapshot:MongoDbSnapshot": "MongoDbSnapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucket",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucket:ObjectBucket": "ObjectBucket"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucketAcl",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucketAcl:ObjectBucketAcl": "ObjectBucketAcl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucketLockConfiguration",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucketLockConfiguration:ObjectBucketLockConfiguration": "ObjectBucketLockConfiguration"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucketPolicy",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucketPolicy:ObjectBucketPolicy": "ObjectBucketPolicy"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucketWebsiteConfiguration",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucketWebsiteConfiguration:ObjectBucketWebsiteConfiguration": "ObjectBucketWebsiteConfiguration"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectItem",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectItem:ObjectItem": "ObjectItem"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/rdbSnapshot",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/rdbSnapshot:RdbSnapshot": "RdbSnapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/redisCluster",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/redisCluster:RedisCluster": "RedisCluster"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/registryNamespace",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/registryNamespace:RegistryNamespace": "RegistryNamespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/sdbDatabase",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/sdbDatabase:SdbDatabase": "SdbDatabase"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/secret",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/secretVersion",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/secretVersion:SecretVersion": "SecretVersion"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/temDomain",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/temDomain:TemDomain": "TemDomain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/temDomainValidation",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/temDomainValidation:TemDomainValidation": "TemDomainValidation"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/temWebhook",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/temWebhook:TemWebhook": "TemWebhook"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpc",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpc:Vpc": "Vpc"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcGatewayNetwork",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcGatewayNetwork:VpcGatewayNetwork": "VpcGatewayNetwork"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPrivateNetwork",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPrivateNetwork:VpcPrivateNetwork": "VpcPrivateNetwork"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGateway",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGateway:VpcPublicGateway": "VpcPublicGateway"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayDhcp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayDhcp:VpcPublicGatewayDhcp": "VpcPublicGatewayDhcp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayDhcpReservation",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayDhcpReservation:VpcPublicGatewayDhcpReservation": "VpcPublicGatewayDhcpReservation"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayIp:VpcPublicGatewayIp": "VpcPublicGatewayIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayIpReverseDns",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayIpReverseDns:VpcPublicGatewayIpReverseDns": "VpcPublicGatewayIpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayPatRule",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayPatRule:VpcPublicGatewayPatRule": "VpcPublicGatewayPatRule"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcRoute",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcRoute:VpcRoute": "VpcRoute"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/webhosting",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/webhosting:Webhosting": "Webhosting"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "inference/deployment",
  "fqn": "pulumiverse_scaleway.inference",
  "classes": {
   "scaleway:inference/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "inference/model",
  "fqn": "pulumiverse_scaleway.inference",
  "classes": {
   "scaleway:inference/model:Model": "Model"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/image",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/image:Image": "Image"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/ip",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/ip:Ip": "Ip"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/ipReverseDns",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/ipReverseDns:IpReverseDns": "IpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/placementGroup",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/placementGroup:PlacementGroup": "PlacementGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/privateNic",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/privateNic:PrivateNic": "PrivateNic"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/securityGroup",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/securityGroup:SecurityGroup": "SecurityGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/securityGroupRules",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/securityGroupRules:SecurityGroupRules": "SecurityGroupRules"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/server",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/server:Server": "Server"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/snapshot",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/userData",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/userData:UserData": "UserData"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/volume",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iot/device",
  "fqn": "pulumiverse_scaleway.iot",
  "classes": {
   "scaleway:iot/device:Device": "Device"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iot/hub",
  "fqn": "pulumiverse_scaleway.iot",
  "classes": {
   "scaleway:iot/hub:Hub": "Hub"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iot/network",
  "fqn": "pulumiverse_scaleway.iot",
  "classes": {
   "scaleway:iot/network:Network": "Network"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iot/route",
  "fqn": "pulumiverse_scaleway.iot",
  "classes": {
   "scaleway:iot/route:Route": "Route"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "ipam/ip",
  "fqn": "pulumiverse_scaleway.ipam",
  "classes": {
   "scaleway:ipam/ip:Ip": "Ip"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "ipam/ipReverseDns",
  "fqn": "pulumiverse_scaleway.ipam",
  "classes": {
   "scaleway:ipam/ipReverseDns:IpReverseDns": "IpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "job/definition",
  "fqn": "pulumiverse_scaleway.job",
  "classes": {
   "scaleway:job/definition:Definition": "Definition"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "kubernetes/acl",
  "fqn": "pulumiverse_scaleway.kubernetes",
  "classes": {
   "scaleway:kubernetes/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "kubernetes/cluster",
  "fqn": "pulumiverse_scaleway.kubernetes",
  "classes": {
   "scaleway:kubernetes/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "kubernetes/pool",
  "fqn": "pulumiverse_scaleway.kubernetes",
  "classes": {
   "scaleway:kubernetes/pool:Pool": "Pool"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/acl",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/backend",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/backend:Backend": "Backend"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/certificate",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/frontend",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/frontend:Frontend": "Frontend"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/ip",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/ip:Ip": "Ip"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/loadBalancer",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/route",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/route:Route": "Route"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/natsAccount",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/natsAccount:NatsAccount": "NatsAccount"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/natsCredentials",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/natsCredentials:NatsCredentials": "NatsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/sns",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/sns:Sns": "Sns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/snsCredentials",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/snsCredentials:SnsCredentials": "SnsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/snsTopic",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/snsTopic:SnsTopic": "SnsTopic"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/snsTopicSubscription",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/snsTopicSubscription:SnsTopicSubscription": "SnsTopicSubscription"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/sqs",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/sqs:Sqs": "Sqs"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/sqsCredentials",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/sqsCredentials:SqsCredentials": "SqsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/sqsQueue",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/sqsQueue:SqsQueue": "SqsQueue"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mongodb/instance",
  "fqn": "pulumiverse_scaleway.mongodb",
  "classes": {
   "scaleway:mongodb/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mongodb/snapshot",
  "fqn": "pulumiverse_scaleway.mongodb",
  "classes": {
   "scaleway:mongodb/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mongodb/user",
  "fqn": "pulumiverse_scaleway.mongodb",
  "classes": {
   "scaleway:mongodb/user:User": "User"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/acl",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/gatewayNetwork",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/gatewayNetwork:GatewayNetwork": "GatewayNetwork"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/privateNetwork",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/privateNetwork:PrivateNetwork": "PrivateNetwork"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/publicGateway",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/publicGateway:PublicGateway": "PublicGateway"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/publicGatewayDhcp",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/publicGatewayDhcp:PublicGatewayDhcp": "PublicGatewayDhcp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/publicGatewayDhcpReservation",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/publicGatewayDhcpReservation:PublicGatewayDhcpReservation": "PublicGatewayDhcpReservation"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/publicGatewayIp",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/publicGatewayIp:PublicGatewayIp": "PublicGatewayIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/publicGatewayIpReverseDns",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/publicGatewayIpReverseDns:PublicGatewayIpReverseDns": "PublicGatewayIpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/publicGatewayPatRule",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/publicGatewayPatRule:PublicGatewayPatRule": "PublicGatewayPatRule"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/route",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/route:Route": "Route"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/vpc",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/vpc:Vpc": "Vpc"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "object/bucket",
  "fqn": "pulumiverse_scaleway.object",
  "classes": {
   "scaleway:object/bucket:Bucket": "Bucket"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "object/bucketAcl",
  "fqn": "pulumiverse_scaleway.object",
  "classes": {
   "scaleway:object/bucketAcl:BucketAcl": "BucketAcl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "object/bucketLockConfiguration",
  "fqn": "pulumiverse_scaleway.object",
  "classes": {
   "scaleway:object/bucketLockConfiguration:BucketLockConfiguration": "BucketLockConfiguration"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "object/bucketPolicy",
  "fqn": "pulumiverse_scaleway.object",
  "classes": {
   "scaleway:object/bucketPolicy:BucketPolicy": "BucketPolicy"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "object/bucketWebsiteConfiguration",
  "fqn": "pulumiverse_scaleway.object",
  "classes": {
   "scaleway:object/bucketWebsiteConfiguration:BucketWebsiteConfiguration": "BucketWebsiteConfiguration"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "object/item",
  "fqn": "pulumiverse_scaleway.object",
  "classes": {
   "scaleway:object/item:Item": "Item"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "observability/alertManager",
  "fqn": "pulumiverse_scaleway.observability",
  "classes": {
   "scaleway:observability/alertManager:AlertManager": "AlertManager"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "observability/cockpit",
  "fqn": "pulumiverse_scaleway.observability",
  "classes": {
   "scaleway:observability/cockpit:Cockpit": "Cockpit"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "observability/grafanaUser",
  "fqn": "pulumiverse_scaleway.observability",
  "classes": {
   "scaleway:observability/grafanaUser:GrafanaUser": "GrafanaUser"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "observability/source",
  "fqn": "pulumiverse_scaleway.observability",
  "classes": {
   "scaleway:observability/source:Source": "Source"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "observability/token",
  "fqn": "pulumiverse_scaleway.observability",
  "classes": {
   "scaleway:observability/token:Token": "Token"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "redis/cluster",
  "fqn": "pulumiverse_scaleway.redis",
  "classes": {
   "scaleway:redis/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "registry/namespace",
  "fqn": "pulumiverse_scaleway.registry",
  "classes": {
   "scaleway:registry/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "secrets/secret",
  "fqn": "pulumiverse_scaleway.secrets",
  "classes": {
   "scaleway:secrets/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "secrets/version",
  "fqn": "pulumiverse_scaleway.secrets",
  "classes": {
   "scaleway:secrets/version:Version": "Version"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "tem/blockedList",
  "fqn": "pulumiverse_scaleway.tem",
  "classes": {
   "scaleway:tem/blockedList:BlockedList": "BlockedList"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "tem/domain",
  "fqn": "pulumiverse_scaleway.tem",
  "classes": {
   "scaleway:tem/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "tem/domainValidation",
  "fqn": "pulumiverse_scaleway.tem",
  "classes": {
   "scaleway:tem/domainValidation:DomainValidation": "DomainValidation"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "tem/webhook",
  "fqn": "pulumiverse_scaleway.tem",
  "classes": {
   "scaleway:tem/webhook:Webhook": "Webhook"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "scaleway",
  "token": "pulumi:providers:scaleway",
  "fqn": "pulumiverse_scaleway",
  "class": "Provider"
 }
]
"""
)
