# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetProjectsProjectResult',
]

@pulumi.output_type
class GetProjectsProjectResult(dict):
    def __init__(__self__, *,
                 created_at: _builtins.str,
                 description: _builtins.str,
                 id: _builtins.str,
                 name: _builtins.str,
                 organization_id: _builtins.str,
                 updated_at: _builtins.str):
        """
        :param _builtins.str created_at: (Computed) The date and time when the project was created.
        :param _builtins.str description: (Computed) The description of the project.
        :param _builtins.str id: (Computed) The unique identifier of the project.
        :param _builtins.str name: (Computed) The name of the project.
        :param _builtins.str organization_id: The unique identifier of the Organization with which the Projects are associated.
               If no default `organization_id` is set, one must be set explicitly in this datasource
        :param _builtins.str updated_at: (Computed) The date and time when the project was updated.
        """
        pulumi.set(__self__, "created_at", created_at)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "organization_id", organization_id)
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        (Computed) The date and time when the project was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        (Computed) The description of the project.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        (Computed) The unique identifier of the project.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (Computed) The name of the project.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        """
        The unique identifier of the Organization with which the Projects are associated.
        If no default `organization_id` is set, one must be set explicitly in this datasource
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        (Computed) The date and time when the project was updated.
        """
        return pulumi.get(self, "updated_at")


